@@ -13,6 +13,8 @@ from asusrouter.tools.readers import read_as_snake_case, read_js_variables
 
 from .vpn_const import MAP_OVPN_CLIENT, MAP_OVPN_SERVER
 
+_TO_IGNORE = ("", "None", "0.0.0.0")  # noqa: S104
+
 
 def read(content: str) -> dict[str, Any]:
     """Read VPN data."""
@@ -26,21 +28,20 @@ def read(content: str) -> dict[str, Any]:
     values: dict[str, Any] = read_js_variables(clean_content(content))
 
     # Values to ignore
-    _to_ignore = ("", "None", "0.0.0.0")
 
     # Read the OpenVPN data
     for party in ("client", "server"):
-        for num in range(1, 10):
+        # Select proper method and state
+        method = read_ovpn_client if party == "client" else read_ovpn_server
+        state = AsusOVPNClient if party == "client" else AsusOVPNServer
+
+        for num in range(1, 11):
             key = f"vpn_{party}{num}_status"
             if key not in values:
                 break
 
-            # Select proper method and state
-            method = read_ovpn_client if party == "client" else read_ovpn_server
-            state = AsusOVPNClient if party == "client" else AsusOVPNServer
-
             # Read the data
-            if values[key] not in _to_ignore:
+            if values[key] not in _TO_IGNORE:
                 vpn[party][num] = method(values[key])
                 vpn[party][num]["state"] = state.CONNECTED
             else:
@@ -48,9 +49,14 @@ def read(content: str) -> dict[str, Any]:
 
             # Read additional data
             for add_key in ("ip", "rip"):
-                key = f"vpn_{party}{num}_{add_key}"
-                if key in values and values[key] not in _to_ignore:
-                    vpn[party][num][add_key] = values[key]
+                search_value = values.get(f"vpn_{party}{num}_{add_key}")
+                if search_value and search_value not in _TO_IGNORE:
+                    vpn[party][num][add_key] = search_value
+
+            # Read remote
+            search_value = vpn[party][num].get("remote")
+            if search_value:
+                vpn[party][num]["remote"] = read_ovpn_remote(search_value)
 
     return vpn
 
@@ -71,10 +77,9 @@ def read_ovpn_client(content: str) -> dict[str, Any]:
 
     for value in MAP_OVPN_CLIENT:
         key_old, key_new, method = value
-        if key_old in content:
-            value = re.search(f"{key_old},(.*?)(?=>)", content)
-            if value:
-                ovpn_client[key_new] = method(value[1]) if method else value[1]
+        match = re.search(f"{key_old},(.*?)(?=>)", content)
+        if match:
+            ovpn_client[key_new] = method(match[1]) if method else match[1]
 
     # --------------------
     # <-- THIS PART IS LEGACY AND CAN BE REMOVED IN THE FUTURE
@@ -86,11 +91,14 @@ def read_ovpn_client(content: str) -> dict[str, Any]:
 def read_ovpn_remote(content: str) -> dict[str, Any]:
     """Read OpenVPN remote data."""
 
-    parts = content.split(",")
-    auth = parts[1]
-    parts = parts[0].split(":")
-    ip_address = parts[0]
-    port = safe_int(parts[1])
+    try:
+        parts = content.split(",")
+        auth = parts[1]
+        parts = parts[0].split(":")
+        ip_address = parts[0]
+        port = safe_int(parts[1])
+    except IndexError:
+        return {}
 
     return {
         "ip": ip_address,
@@ -123,8 +131,7 @@ def read_ovpn_server(content: str) -> dict[str, Any]:
             header = re.search(f"HEADER,{key_old},(.*?)(?=>)", content)
             if header:
                 keys_raw = header[1].split(",")
-                for element in keys_raw:
-                    keys.append(read_as_snake_case(element))
+                keys = [read_as_snake_case(element) for element in keys_raw]
                 flag = True
 
             # Hide header
@@ -137,12 +144,8 @@ def read_ovpn_server(content: str) -> dict[str, Any]:
                     break
                 if flag:
                     cut = value[1].split(",")
-                    i = 0
-                    array = {}
-                    while i < len(cut) and i < len(keys):
-                        array[keys[i]] = cut[i]
-                        i += 1
-                    ovpn_server[key_new].append(array.copy())
+                    array = dict(zip(keys, cut))
+                    ovpn_server[key_new].append(array)
                 else:
                     ovpn_server[key_new].append(value[1])
                 content = content.replace(f"{key_old},{value[1]}", "USED-")
@@ -157,7 +160,8 @@ def process(data: dict[str, Any]) -> dict[AsusData, Any]:
     """Process VPN data."""
 
     vpn: dict[AsusData, Any] = {
-        AsusData.OPENVPN: data,
+        AsusData.OPENVPN_CLIENT: data.get("client"),
+        AsusData.OPENVPN_SERVER: data.get("server"),
     }
 
     return vpn
