@@ -3,18 +3,19 @@
 This module is used to convert some of the AsusRouter data
 to a format easy to handle by Home Assistant integration.
 
-Native AsusRouter integration: https://github.com/vaskivskyi/ha-asusrouter."""
-
+Native AsusRouter integration: https://github.com/vaskivskyi/ha-asusrouter.
+"""
 
 from __future__ import annotations
 
-import logging
 from enum import Enum
-from typing import Any, Optional
+import logging
+from typing import Any
 
 from asusrouter.modules.data import AsusData
 from asusrouter.modules.state import AsusState
-from asusrouter.tools.converters import as_dict, flatten_dict, list_from_dict
+from asusrouter.modules.vpnc import AsusVPNC
+from asusrouter.tools.converters import flatten_dict, list_from_dict
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -39,9 +40,13 @@ SENSORS_VPN = {
 }
 
 
-def convert_to_ha_sensors(data: dict[str, Any], datatype: AsusData) -> list[str]:
-    """Convert available data to the list of sensors
-    compatible with Home Assistant."""
+def convert_to_ha_sensors(
+    data: dict[str, Any], datatype: AsusData
+) -> list[str]:
+    """Convert available data.
+
+    The result is a list of sensors compatible with Home Assistant.
+    """
 
     sensors = []
 
@@ -59,19 +64,44 @@ def convert_to_ha_sensors(data: dict[str, Any], datatype: AsusData) -> list[str]
     return sensors
 
 
+def convert_to_ha_data(data: dict[str, Any]) -> dict[str, Any]:
+    """Convert available data to the HA-compatible dictionary."""
+
+    def convert_recursive(data: dict[str, Any]) -> dict[str, Any]:
+        """Convert data to the HA-compatible dictionary recursively."""
+        return {
+            key: convert_recursive(value)
+            if isinstance(value, dict)
+            else convert_to_ha_state_bool(value)
+            if key.endswith(("state", "link"))
+            else value
+            for key, value in data.items()
+        }
+
+    # Flatten the dictionary
+    # Skip all the `list`, `clients` etc keys - this data should be preserved
+    output = flatten_dict(data, exclude=["list", "clients", "rules"])
+
+    # Convert values to HA-compatible format
+    if output is not None:
+        return convert_recursive(output)
+
+    return {}
+
+
 def convert_to_ha_sensors_by_map(
     data: dict[str, Any], sensor_map: list[str]
 ) -> list[str]:
-    """Convert available data to the list of sensors
-    using static map."""
+    """Convert available data to the list of sensors using static map."""
 
     _LOGGER.debug("Converting data to the list of sensors by map: %s", data)
 
     sensors = []
 
     for sensor in data:
-        for sensor_type in sensor_map:
-            sensors.append(f"{sensor}_{sensor_type}")
+        sensors.extend(
+            [f"{sensor}_{sensor_type}" for sensor_type in sensor_map]
+        )
 
     return sensors
 
@@ -79,17 +109,25 @@ def convert_to_ha_sensors_by_map(
 def convert_to_ha_sensors_by_map_2(
     data: dict[str, Any], sensor_map: dict[str, list[str]]
 ) -> list[str]:
-    """Convert available data to the list of sensors
-    using first two levels of the data and static map."""
+    """Convert available data to the list of sensors.
 
-    _LOGGER.debug("Converting data to the list of sensors by 2 levels: %s", data)
+    Use first two levels of the data and static map.
+    """
+
+    _LOGGER.debug(
+        "Converting data to the list of sensors by 2 levels: %s", data
+    )
 
     sensors = []
 
-    for sensor in data:
-        for sensor_id in data[sensor]:
-            for sensor_type in sensor_map.get(sensor, []):
-                sensors.append(f"{sensor}_{sensor_id}_{sensor_type}")
+    for sensor, sensor_ids in data.items():
+        sensors.extend(
+            [
+                f"{sensor}_{sensor_id}_{sensor_type}"
+                for sensor_id in sensor_ids
+                for sensor_type in sensor_map.get(sensor, [])
+            ]
+        )
 
     return sensors
 
@@ -103,11 +141,12 @@ def convert_to_ha_sensors_group(data: dict[str, Any]) -> list[str]:
 def convert_to_ha_sensors_list(data: dict[str, Any]) -> list[str]:
     """Convert all the available data to the list of sensors."""
 
-    flat = as_dict(flatten_dict(data))
-    return list_from_dict(flat)
+    return list_from_dict(convert_to_ha_data(data))
 
 
-def convert_to_ha_state_bool(data: AsusState | Optional[bool]) -> Optional[bool]:
+def convert_to_ha_state_bool(  # noqa: PLR0911
+    data: AsusState | bool | None,
+) -> bool | None:
     """Convers native state to a binary state."""
 
     # Check whether the state is None
@@ -118,6 +157,24 @@ def convert_to_ha_state_bool(data: AsusState | Optional[bool]) -> Optional[bool]
     if isinstance(data, bool):
         return data
 
+    # Special cases
+    if isinstance(data, AsusVPNC):
+        match data:
+            case a if a in (
+                AsusVPNC.CONNECTED,
+                AsusVPNC.CONNECTING,
+                AsusVPNC.ON,
+            ):
+                return True
+            case a if a in (
+                AsusVPNC.OFF,
+                AsusVPNC.DISCONNECTED,
+                AsusVPNC.ERROR,
+            ):
+                return False
+            case _:
+                return None
+
     # Check whether the state is based on (int, Enum)
     if isinstance(data, int) and isinstance(data, Enum):
         if data.value == 0:
@@ -131,7 +188,7 @@ def convert_to_ha_state_bool(data: AsusState | Optional[bool]) -> Optional[bool]
 
 
 def convert_to_ha_string(data: Any) -> str:
-    """Converts data to a string."""
+    """Convert data to a string."""
 
     # Check if we have None
     if data is None:
