@@ -2,12 +2,19 @@
 
 from __future__ import annotations
 
-import logging
+from collections.abc import Awaitable, Callable
 from enum import Enum
-from typing import Any, Awaitable, Callable
+import logging
+from typing import Any
 
 _LOGGER = logging.getLogger(__name__)
 
+ACTION_MODE = "action_mode"
+APPLY = "apply"
+ARGUMENTS = "arguments"
+EXPECT_MODIFY = "expect_modify"
+SERVICE = "service"
+
 
 class AsusSystem(str, Enum):
     """Asus system enum.
@@ -16,7 +23,8 @@ class AsusSystem(str, Enum):
     services depends on the router model and firmware version.
 
     Some services might not be tested and might not work as expected. Use with
-    caution and at your own risk."""
+    caution and at your own risk.
+    """
 
     # ---------------------
     # DISCLAIMER: Migration to the new format
@@ -45,11 +53,17 @@ class AsusSystem(str, Enum):
     )
     AIMESH_REBOOT = "device_reboot"  # Restart router + all nodes
     AIMESH_REBUILD = "re_reconnect"  # Rebuild AiMesh
+    NODE_CONFIG_CHANGE = "config_changed"  # Change node configuration
+    NODE_REBOOT = "node_reboot"  # Reboot a node by MAC (when specified)
     REBUILD_AIMESH = "_depr_re_reconnect"  # Rebuild AiMesh / legacy name
     # ---------------------
     # Aura
     AURA_RESTART = "restart_ledg"  # Restart Aura RGB
     # ---------------------
+    # DDNS
+    DDNS_RESTART = "restart_ddns_le"  # Restart DDNS
+    RESTART_DDNS_LE = "_depr_restart_ddns_le"  # Restart DDNS / legacy name
+    # ---------------------
     # Firmware
     FIRMWARE_CHECK = "firmware_check"  # Check for firmware update
     # Firmware upgrade will upgrade the firmware to the latest version
@@ -70,12 +84,11 @@ class AsusSystem(str, Enum):
     RESTART_CHPASS = "restart_chpass"
     RESTART_CLOUDSYNC = "restart_cloudsync"  # AiCloud 2.0 sync
     RESTART_CP = "restart_CP"  # Captive Portal
-    RESTART_DDNS_LE = "restart_ddns_le"
     RESTART_DEFAULT_WAN = "restart_default_wan"  # Default WAN
     RESTART_DISKMON = "restart_diskmon"  # Disk monitor
     RESTART_DNSFILTER = "restart_dnsfilter"  # DNS filter
     RESTART_DNSMASQ = "restart_dnsmasq"  # DNS
-    RESTART_DNSQD = "restart_dnsqd"  #
+    RESTART_DNSQD = "restart_dnsqd"
     RESTART_FIREWALL = "restart_firewall"  # Firewall
     RESTART_FTPD = "restart_ftpd"  # FTP server
     RESTART_FTPSAMBA = "restart_ftpsamba"
@@ -146,6 +159,8 @@ class AsusSystem(str, Enum):
 AsusSystemDeprecated = {
     # AiMesh
     AsusSystem.REBUILD_AIMESH: (AsusSystem.AIMESH_REBUILD, None),
+    # DDNS
+    AsusSystem.RESTART_DDNS_LE: (AsusSystem.DDNS_RESTART, None),
     # Upgrades and updates
     AsusSystem.RESTART_UPGRADE: (AsusSystem.UPGRADE_RESTART, None),
     AsusSystem.START_UPGRADE: (AsusSystem.UPGRADE_START, None),
@@ -156,31 +171,52 @@ AsusSystemDeprecated = {
 # Map AsusSystem special cases to service calls
 STATE_MAP: dict[AsusSystem, dict[str, Any]] = {
     AsusSystem.AIMESH_REBOOT: {
-        "service": None,
-        "arguments": {"action_mode": "device_reboot"},
-        "apply": False,
-        "expect_modify": False,
+        SERVICE: None,
+        ARGUMENTS: {ACTION_MODE: AsusSystem.AIMESH_REBOOT.value},
+        APPLY: False,
+        EXPECT_MODIFY: False,
+    },
+    AsusSystem.NODE_CONFIG_CHANGE: {
+        SERVICE: None,
+        ARGUMENTS: {ACTION_MODE: AsusSystem.NODE_CONFIG_CHANGE.value},
+        APPLY: False,
+        EXPECT_MODIFY: False,
+    },
+    AsusSystem.NODE_REBOOT: {
+        SERVICE: None,
+        # NODE_REBOOT is an alias for AIMESH_REBOOT, but it requires
+        # passing a node MAC address. For the safety, this AsusSystem
+        # state is separated to avoid accidental reboot of the whole
+        # AiMesh network.
+        ARGUMENTS: {ACTION_MODE: AsusSystem.AIMESH_REBOOT.value},
+        APPLY: False,
+        EXPECT_MODIFY: False,
     },
     AsusSystem.FIRMWARE_CHECK: {
-        "service": None,
-        "arguments": {"action_mode": "firmware_check"},
-        "apply": False,
-        "expect_modify": False,
+        SERVICE: None,
+        ARGUMENTS: {ACTION_MODE: AsusSystem.FIRMWARE_CHECK.value},
+        APPLY: False,
+        EXPECT_MODIFY: False,
     },
     AsusSystem.FIRMWARE_UPGRADE: {
-        "service": None,
-        "arguments": {"action_mode": "firmware_upgrade"},
-        "apply": False,
-        "expect_modify": False,
+        SERVICE: None,
+        ARGUMENTS: {ACTION_MODE: AsusSystem.FIRMWARE_UPGRADE.value},
+        APPLY: False,
+        EXPECT_MODIFY: False,
     },
     AsusSystem.UPDATE_CLIENTS: {
-        "service": None,
-        "arguments": {"action_mode": "update_client_list"},
-        "apply": False,
-        "expect_modify": False,
+        SERVICE: None,
+        ARGUMENTS: {ACTION_MODE: AsusSystem.UPDATE_CLIENTS.value},
+        APPLY: False,
+        EXPECT_MODIFY: False,
     },
 }
 
+ARGUMENTS_APPEND: dict[AsusSystem, list[str]] = {
+    AsusSystem.NODE_CONFIG_CHANGE: ["re_mac", "config"],
+    AsusSystem.NODE_REBOOT: ["device_list"],
+}
+
 
 async def set_state(
     callback: Callable[..., Awaitable[bool]],
@@ -192,8 +228,10 @@ async def set_state(
     # Check and notify if the state is deprecated
     if state in AsusSystemDeprecated:
         repl_state, repl_ver = AsusSystemDeprecated[state]
-        message = f"Deprecated state `{state.name}` from `AsusSystem` \
-enum used. Use `{repl_state.name}` instead"
+        message = (
+            f"Deprecated state `{state.name}` from `AsusSystem` "
+            f"enum used. Use `{repl_state.name}` instead"
+        )
         if repl_ver:
             message += f". This state will be removed in version {repl_ver}"
         _LOGGER.warning(
@@ -201,16 +239,35 @@ enum used. Use `{repl_state.name}` instead"
         )
         state = repl_state
 
+    arguments: dict[str, Any] = kwargs.get(ARGUMENTS, {})
+
     # Get the arguments for the callback function based on the state
-    callback_args = STATE_MAP.get(
+    callback_args: dict[str, Any] = STATE_MAP.get(
         state,
         {
-            "service": state.value,
-            "arguments": kwargs.get("arguments", {}),
-            "apply": True,
-            "expect_modify": kwargs.get("expect_modify", False),
+            SERVICE: state.value,
+            ARGUMENTS: arguments,
+            APPLY: True,
+            EXPECT_MODIFY: kwargs.get(EXPECT_MODIFY, False),
         },
     )
 
+    # Append additional arguments if the state is in the append list
+    if state in ARGUMENTS_APPEND:
+        search_args = ARGUMENTS_APPEND[state]
+        if not all(arg in kwargs for arg in search_args):
+            _LOGGER.error(
+                "Setting state `%s` requires ALL of the following "
+                "arguments: %s",
+                state,
+                search_args,
+            )
+            return False
+
+        # Append the arguments to the callback arguments
+        callback_args[ARGUMENTS].update(
+            {arg: kwargs[arg] for arg in search_args}
+        )
+
     # Run the service
     return await callback(**callback_args)
